Class: StringIO
- Inherits:
-
Object
- Object
- StringIO
- Defined in:
- lib/task_scheduler/windows_scheduler.rb
Instance Method Summary collapse
-
#run ⇒ Object
I built this method because I couldn’t test with the system method in the create_task method.
Instance Method Details
#run ⇒ Object
I built this method because I couldn’t test with the system method in the create_task method
76 77 78 |
# File 'lib/task_scheduler/windows_scheduler.rb', line 76 def run system(string) end |